@@ -1,7 +1,9 @@
 package Sah::Schemas::App::cryp;
 
-our $DATE = '2018-06-09'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'Sah-Schemas-App-cryp'; # DIST
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas for the 'cryp' app family
@@ -18,7 +20,7 @@ Sah::Schemas::App::cryp - Various Sah schemas for the 'cryp' app family
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schemas::App::cryp (from Perl distribution Sah-Schemas-App-cryp), released on 2018-06-09.
+This document describes version 0.004 of Sah::Schemas::App::cryp (from Perl distribution Sah-Schemas-App-cryp), released on 2019-11-29.
 
 =head1 HOMEPAGE
 
@@ -52,7 +54,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
